#pragma once

namespace precice::math {

constexpr double PI = 3.1415926535897931;

}
